@@ -1,8 +1,10 @@
 package Crypt::Random::Source::Base;
 # ABSTRACT: Abstract base class for L<Crypt::Random::Source> classes
-$Crypt::Random::Source::Base::VERSION = '0.10';
-use Any::Moose;
-use namespace::autoclean;
+
+our $VERSION = '0.13';
+
+use Moo;
+use namespace::clean;
 
 sub available { 0 }
 
@@ -52,11 +54,11 @@ Crypt::Random::Source::Base - Abstract base class for L<Crypt::Random::Source> c
 
 =head1 VERSION
 
-version 0.10
+version 0.13
 
 =head1 SYNOPSIS
 
-    use Moose;
+    use Moo;
     extends qw(Crypt::Random::Source::Base);
 
 =head1 DESCRIPTION
@@ -105,11 +107,16 @@ sources be tried before known bad (slower, less available) sources.
 
 Provided for compatibility with L<Crypt::Random>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Crypt-Random-Source>
+(or L<bug-Crypt-Random-Source@rt.cpan.org|mailto:bug-Crypt-Random-Source@rt.cpan.org>).
+
 =head1 AUTHOR
 
 יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2008 by Yuval Kogman.
 
