@@ -1,18 +1,21 @@
 package Crypt::Random::Source::Base::Handle;
 # ABSTRACT: L<IO::Handle> based random data sources
-$Crypt::Random::Source::Base::Handle::VERSION = '0.10';
-use Any::Moose;
+
+our $VERSION = '0.13';
+
+use Moo;
+use Types::Standard qw(Bool);
 
 use Errno;
 
 use Carp qw(croak);
 use IO::Handle;
-use namespace::autoclean;
+use namespace::clean;
 
 extends qw(Crypt::Random::Source::Base);
 
 has allow_under_read => (
-    isa => "Bool",
+    isa => Bool,
     is  => "rw",
     default => 0,
 );
@@ -24,9 +27,10 @@ has reread_attempts => (
 
 has handle => (
     is => "rw",
+    lazy => 1,
+    builder => 1,
     predicate  => "has_handle",
     clearer    => "clear_handle",
-    lazy_build => 1,
 );
 
 sub blocking { shift->handle->blocking(@_) }
@@ -106,11 +110,11 @@ Crypt::Random::Source::Base::Handle - L<IO::Handle> based random data sources
 
 =head1 VERSION
 
-version 0.10
+version 0.13
 
 =head1 SYNOPSIS
 
-    use Moose;
+    use Moo;
     extends qw(Crypt::Random::Source::Base::Handle);
 
     sub open_handle {
@@ -194,11 +198,16 @@ true it will just return the partial buffer.
 
 Abstract method, should return an L<IO::Handle> to use.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Crypt-Random-Source>
+(or L<bug-Crypt-Random-Source@rt.cpan.org|mailto:bug-Crypt-Random-Source@rt.cpan.org>).
+
 =head1 AUTHOR
 
 יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2008 by Yuval Kogman.
 
