@@ -1,14 +1,18 @@
 package Crypt::Random::Source::Base::RandomDevice;
 # ABSTRACT: Base class for random devices
-$Crypt::Random::Source::Base::RandomDevice::VERSION = '0.10';
-use Any::Moose;
+
+our $VERSION = '0.13';
+
+use Moo;
 
 extends qw(Crypt::Random::Source::Base::File);
-use namespace::autoclean;
+use namespace::clean;
 
 sub rank { 100 } # good quality, pretty fast
 
 has '+path' => (
+    lazy => 1,
+    required => 0,
     builder => "default_path",
 );
 
@@ -42,12 +46,11 @@ Crypt::Random::Source::Base::RandomDevice - Base class for random devices
 
 =head1 VERSION
 
-version 0.10
+version 0.13
 
 =head1 SYNOPSIS
 
-    use Moose;
-
+    use Moo;
     extends qw(Crypt::Random::Source::Base::RandomDevice);
 
     sub default_path { "/dev/myrandom" }
@@ -59,11 +62,16 @@ This is a base class for random device sources.
 See L<Crypt::Random::Source::Strong::devrandom> and
 L<Crypt::Random::Source::Weak::devurandom> for actual implementations.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Crypt-Random-Source>
+(or L<bug-Crypt-Random-Source@rt.cpan.org|mailto:bug-Crypt-Random-Source@rt.cpan.org>).
+
 =head1 AUTHOR
 
 יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2008 by Yuval Kogman.
 
