@@ -1,8 +1,10 @@
 package Crypt::Random::Source::Strong;
 # ABSTRACT: Abstract base class for strong random data sources
-$Crypt::Random::Source::Strong::VERSION = '0.10';
-use Any::Moose;
-use namespace::autoclean;
+
+our $VERSION = '0.13';
+
+use Moo;
+use namespace::clean;
 
 sub is_strong { 1 }
 
@@ -18,12 +20,11 @@ Crypt::Random::Source::Strong - Abstract base class for strong random data sourc
 
 =head1 VERSION
 
-version 0.10
+version 0.13
 
 =head1 SYNOPSIS
 
-    use Moose;
-
+    use Moo;
     extends qw(Crypt::Random::Source::Strong);
 
 =head1 DESCRIPTION
@@ -36,11 +37,16 @@ This is an abstract base class. There isn't much to describe.
 
 Returns true
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Crypt-Random-Source>
+(or L<bug-Crypt-Random-Source@rt.cpan.org|mailto:bug-Crypt-Random-Source@rt.cpan.org>).
+
 =head1 AUTHOR
 
 יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2008 by Yuval Kogman.
 
